==> esp32c3-0.3.0.crate: esp32c3-0.3.0/src/hmac/soft_jtag_ctrl.rs <==
#[doc = "Register `SOFT_JTAG_CTRL` writer"]
pub struct W(crate::W<SOFT_JTAG_CTRL_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SOFT_JTAG_CTRL_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SOFT_JTAG_CTRL_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SOFT_JTAG_CTRL_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SOFT_JTAG_CTRL` writer - Turn on JTAG verification."]
pub struct SOFT_JTAG_CTRL_W<'a> {
    w: &'a mut W,
}
impl<'a> SOFT_JTAG_CTRL_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
impl W {
    #[doc = "Bit 0 - Turn on JTAG verification."]
    #[inline(always)]
    pub fn soft_jtag_ctrl(&mut self) -> SOFT_JTAG_CTRL_W {
        SOFT_JTAG_CTRL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Jtag register 0.\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [soft_jtag_ctrl](index.html) module"]
pub struct SOFT_JTAG_CTRL_SPEC;
impl crate::RegisterSpec for SOFT_JTAG_CTRL_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [soft_jtag_ctrl::W](W) writer structure"]
impl crate::Writable for SOFT_JTAG_CTRL_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SOFT_JTAG_CTRL to value 0"]
impl crate::Resettable for SOFT_JTAG_CTRL_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/hmac/soft_jtag_ctrl.rs <==
#[doc = "Register `SOFT_JTAG_CTRL` writer"]
pub struct W(crate::W<SOFT_JTAG_CTRL_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SOFT_JTAG_CTRL_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SOFT_JTAG_CTRL_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SOFT_JTAG_CTRL_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SOFT_JTAG_CTRL` writer - Turn on JTAG verification."]
pub struct SOFT_JTAG_CTRL_W<'a> {
    w: &'a mut W,
}
impl<'a> SOFT_JTAG_CTRL_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
        self.w
    }
}
impl W {
    #[doc = "Bit 0 - Turn on JTAG verification."]
    #[inline(always)]
    pub fn soft_jtag_ctrl(&mut self) -> SOFT_JTAG_CTRL_W {
        SOFT_JTAG_CTRL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Jtag register 0.\n\nThis register you can [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [soft_jtag_ctrl]
(index.html) module"]
pub struct SOFT_JTAG_CTRL_SPEC;
impl crate::RegisterSpec for SOFT_JTAG_CTRL_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [soft_jtag_ctrl::W]
(W) writer structure"]
impl crate::Writable for SOFT_JTAG_CTRL_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SOFT_JTAG_CTRL to value 0"]
impl crate::Resettable for SOFT_JTAG_CTRL_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
